Struct waffle::GlobalData
source · pub struct GlobalData {
pub ty: Type,
pub value: Option<u64>,
pub mutable: bool,
}Fields
ty: Typevalue: Option<u64>mutable: boolTrait Implementations
sourceimpl Clone for GlobalData
impl Clone for GlobalData
sourcefn clone(&self) -> GlobalData
fn clone(&self) -> GlobalData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for GlobalData
impl Debug for GlobalData
sourceimpl Hash for GlobalData
impl Hash for GlobalData
sourceimpl Ord for GlobalData
impl Ord for GlobalData
sourcefn cmp(&self, other: &GlobalData) -> Ordering
fn cmp(&self, other: &GlobalData) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for GlobalData
impl PartialEq for GlobalData
sourcefn eq(&self, other: &GlobalData) -> bool
fn eq(&self, other: &GlobalData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for GlobalData
impl PartialOrd for GlobalData
sourcefn partial_cmp(&self, other: &GlobalData) -> Option<Ordering>
fn partial_cmp(&self, other: &GlobalData) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for GlobalData
impl StructuralPartialEq for GlobalData