Struct waffle::MemoryData
source · pub struct MemoryData {
pub initial_pages: usize,
pub maximum_pages: Option<usize>,
pub segments: Vec<MemorySegment>,
}Fields
initial_pages: usizemaximum_pages: Option<usize>segments: Vec<MemorySegment>Trait Implementations
sourceimpl Clone for MemoryData
impl Clone for MemoryData
sourcefn clone(&self) -> MemoryData
fn clone(&self) -> MemoryData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MemoryData
impl Debug for MemoryData
sourceimpl Hash for MemoryData
impl Hash for MemoryData
sourceimpl Ord for MemoryData
impl Ord for MemoryData
sourcefn cmp(&self, other: &MemoryData) -> Ordering
fn cmp(&self, other: &MemoryData) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for MemoryData
impl PartialEq for MemoryData
sourcefn eq(&self, other: &MemoryData) -> bool
fn eq(&self, other: &MemoryData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for MemoryData
impl PartialOrd for MemoryData
sourcefn partial_cmp(&self, other: &MemoryData) -> Option<Ordering>
fn partial_cmp(&self, other: &MemoryData) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for MemoryData
impl StructuralPartialEq for MemoryData