Struct waffle::SignatureData
source · pub struct SignatureData {
pub params: Vec<Type>,
pub returns: Vec<Type>,
}Fields
params: Vec<Type>returns: Vec<Type>Trait Implementations
sourceimpl Clone for SignatureData
impl Clone for SignatureData
sourcefn clone(&self) -> SignatureData
fn clone(&self) -> SignatureData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SignatureData
impl Debug for SignatureData
sourceimpl From<&FuncType> for SignatureData
impl From<&FuncType> for SignatureData
sourceimpl From<FuncType> for SignatureData
impl From<FuncType> for SignatureData
sourceimpl Hash for SignatureData
impl Hash for SignatureData
sourceimpl Ord for SignatureData
impl Ord for SignatureData
sourcefn cmp(&self, other: &SignatureData) -> Ordering
fn cmp(&self, other: &SignatureData) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for SignatureData
impl PartialEq for SignatureData
sourcefn eq(&self, other: &SignatureData) -> bool
fn eq(&self, other: &SignatureData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for SignatureData
impl PartialOrd for SignatureData
sourcefn partial_cmp(&self, other: &SignatureData) -> Option<Ordering>
fn partial_cmp(&self, other: &SignatureData) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for SignatureData
impl StructuralPartialEq for SignatureData